#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_FREXP_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_FREXP_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/frexp.hpp>

#endif
